ControlCenterUnsupportedException class

Thrown when controls are not available on the current platform: any platform other than iOS, or iOS older than 18.

Implemented types

Constructors

ControlCenterUnsupportedException(String message)
Creates the exception with a human readable message.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String
Why controls are unavailable.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited