ControlCenterUnsupportedException class
Thrown when controls are not available on the current platform: any platform other than iOS, or iOS older than 18.
- Implemented types
Constructors
- ControlCenterUnsupportedException(String message)
-
Creates the exception with a human readable
message.const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited